```
Usage: vcd vm update [OPTIONS] <vapp-name> <vm-name>

Options:
  --cpu <cpu>        Number of virtual CPUs to configure the VM.
  --cores <cores>    Number of cores per socket.
  --memory <memory>  Memory to configure the VM.
  -h, --help         Show this message and exit.

```
